Please see [https://docs.mlcommons.org/cm4mlops/scripts/AI-ML-models/get-ml-model-dlrm-terabyte](https://docs.mlcommons.org/cm4mlops/scripts/AI-ML-models/get-ml-model-dlrm-terabyte) for the documentation of this CM script.
